function g = mtimes( e, f )

%---------------------------------------------------------------------------
%   Series connection of two state space systems. The connection is
%   e -> f
%   The inputs to e are the system inputs and the outputs
%   of f are the system outputs
%---------------------------------------------------------------------------
%   Form:
%   g = mtimes( e, f )
%---------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   e           (:)   Object of class statespace
%   f           (:)   Object of class statespace
%
%   -------
%   Outputs
%   -------
%   g           (:)   Series connection
%
%---------------------------------------------------------------------------

%---------------------------------------------------------------------------
%   Copyright (c) 1997 Princeton Satellite Systems, Inc.
%   All rights reserved.
%---------------------------------------------------------------------------

if( ~strcmp(e.sType,f.sType) )
	error(['Cannot connect a ',e.sType,' to a ',f.sType]);
end

if( e.dT ~= f.dT )
	error('Time steps must be the same for each system');
end

[a, b, c, d] = Series( e.a, e.b, e.c, e.d, f.a, f.b, f.c, f.d );

name   = [e.name,' * ',f.name];
states = strvcat(e.states,f.states);

g = statespace( a, b, c, d, name, states, e.inputs, f.outputs,...
                e.sType, e.dT  );

% PSS internal file version information
%--------------------------------------
% $Date: 2006-02-03 14:40:12 -0500 (Fri, 03 Feb 2006) $
% $Revision: 4799 $
