function g = plus( e, f )

%---------------------------------------------------------------------------
%   Parallel connection of two state space systems.
%   The connection is
%   [ e ]
%   [ f ]
%---------------------------------------------------------------------------
%   Form:
%   g = plus( e, f )
%---------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   e           (:)   Object of class statespace
%   f           (:)   Object of class statespace
%
%   -------
%   Outputs
%   -------
%   g           (:)   Parallel connection
%
%---------------------------------------------------------------------------

%---------------------------------------------------------------------------
%   Copyright (c) 1997 Princeton Satellite Systems, Inc.
%   All rights reserved.
%---------------------------------------------------------------------------

if( ~strcmp(e.sType,f.sType) )
	error(['Cannot connect a ',e.sType,' to a ',f.sType]);
end

if( e.dT ~= f.dT )
	error('Time steps must be the same for each system');
end

[a, b, c, d] = Parallel( e.a, e.b, e.c, e.d, f.a, f.b, f.c, f.d );

g = statespace( a, b, c, d, [e.name,' + ',f.name],...
                strvcat(e.states,f.states),...
                strvcat(e.inputs,f.inputs),...
                strvcat(e.outputs,f.outputs) );

% PSS internal file version information
%--------------------------------------
% $Date: 2006-02-03 14:40:12 -0500 (Fri, 03 Feb 2006) $
% $Revision: 4799 $
